pub enum BlockRequest {
GetInfo {
responder: BlockGetInfoResponder,
},
OpenSession {
session: ServerEnd<SessionMarker>,
control_handle: BlockControlHandle,
},
OpenSessionWithOptions {
session: ServerEnd<SessionMarker>,
mappings: Vec<BlockOffsetMapping>,
control_handle: BlockControlHandle,
},
GetTypeGuid {
responder: BlockGetTypeGuidResponder,
},
GetInstanceGuid {
responder: BlockGetInstanceGuidResponder,
},
GetName {
responder: BlockGetNameResponder,
},
GetMetadata {
responder: BlockGetMetadataResponder,
},
QuerySlices {
start_slices: Vec<u64>,
responder: BlockQuerySlicesResponder,
},
GetVolumeInfo {
responder: BlockGetVolumeInfoResponder,
},
Extend {
start_slice: u64,
slice_count: u64,
responder: BlockExtendResponder,
},
Shrink {
start_slice: u64,
slice_count: u64,
responder: BlockShrinkResponder,
},
Destroy {
responder: BlockDestroyResponder,
},
}Expand description
Defines access to a device which is accessible in block-granularity chunks for reading and writing.
Variants
GetInfo
Get information about the underlying block device.
Fields
responder: BlockGetInfoResponderOpenSession
Opens a new FIFO-based session on the block device.
OpenSessionWithOptions
Opens a new FIFO-based session on the block device, with additional options.
Mappings
The mappings argument is a list of logical -> physical block mappings, which the server
will transparently apply to device offsets in block FIFO requests within this session.
The mappings are logically contiguous starting from logical offset 0.
This interface is intended to be used internally between nested Block implementations, in order to provide passthrough I/O. For example, a fixed partition map (e.g. GPT) will serve a Block protocol for each partition, and will respond to OpenSession requests by calling OpenSessionWithOptions on the underlying block device, providing mappings which translate block offsets which are relative to (and bounded by) the partition to absolute offsets on the device.
Mappings can only ever restrict the visible range of a device; servers will reject mappings which exceed the range of the device.
If mappings is empty, the session channel will be closed with epitaph
ZX_ERR_INVALID_ARGS.
Fields
session: ServerEnd<SessionMarker>mappings: Vec<BlockOffsetMapping>control_handle: BlockControlHandleGetTypeGuid
Gets the type GUID of the partition (if one exists). If the partition has no type GUID, ZX_ERR_NOT_SUPPORTED is returned.
Fields
responder: BlockGetTypeGuidResponderGetInstanceGuid
Gets the instance GUID of the partition (if one exists). If the partition has no instance GUID, ZX_ERR_NOT_SUPPORTED is returned.
Fields
responder: BlockGetInstanceGuidResponderGetName
Gets the name of the partition (if one exists). If the partition has no name, ZX_ERR_NOT_SUPPORTED is returned.
Fields
responder: BlockGetNameResponderGetMetadata
Gets the metadata for the partition.
Fields may be absent if the partition doesn’t have the given metadata.
Fields
responder: BlockGetMetadataResponderQuerySlices
Returns the number of contiguous allocated (or unallocated) vslices starting from each vslice.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
GetVolumeInfo
Returns the information about this volume and the volume manager it is embedded in.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Fields
responder: BlockGetVolumeInfoResponderExtend
Extends the mapping of this partition.
The ability to extend the partition is dependent on having sufficient free space on the underlying device, having sufficient free slots for tracking the bytes in the volume manager header, and the partition limit (see VolumeManager.SetPartitionLimit).
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Shrink
Shrinks a virtual partition. Returns ZX_OK if ANY slices are
freed, even if part of the requested range contains unallocated slices.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Destroy
Destroys the current volume, removing it from the VolumeManager, and freeing all underlying storage. The connection to the volume is also closed.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Fields
responder: BlockDestroyResponderImplementations
Sourceimpl BlockRequest
impl BlockRequest
pub fn into_get_info(self) -> Option<BlockGetInfoResponder>
pub fn into_open_session( self, ) -> Option<(ServerEnd<SessionMarker>, BlockControlHandle)>
pub fn into_open_session_with_options( self, ) -> Option<(ServerEnd<SessionMarker>, Vec<BlockOffsetMapping>, BlockControlHandle)>
pub fn into_get_type_guid(self) -> Option<BlockGetTypeGuidResponder>
pub fn into_get_instance_guid(self) -> Option<BlockGetInstanceGuidResponder>
pub fn into_get_name(self) -> Option<BlockGetNameResponder>
pub fn into_get_metadata(self) -> Option<BlockGetMetadataResponder>
pub fn into_query_slices(self) -> Option<(Vec<u64>, BlockQuerySlicesResponder)>
pub fn into_get_volume_info(self) -> Option<BlockGetVolumeInfoResponder>
pub fn into_extend(self) -> Option<(u64, u64, BlockExtendResponder)>
pub fn into_shrink(self) -> Option<(u64, u64, BlockShrinkResponder)>
pub fn into_destroy(self) -> Option<BlockDestroyResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL