pub enum MapperRequest {
OpenSession {
session: ServerEnd<MapperSessionMarker>,
mapping_vmo: Vmo,
port: Option<Port>,
delivery_queue: Option<Vmo>,
responder: MapperOpenSessionResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: MapperControlHandle,
method_type: MethodType,
},
}Expand description
Exposed by the block driver, routed via fshost to pkg-cache.
Variants
OpenSession
Bootstraps the driver mapper with the mapping VMO and verifier handles.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: MapperControlHandle
method_type: MethodTypeImplementations
Sourceimpl MapperRequest
impl MapperRequest
pub fn into_open_session( self, ) -> Option<(ServerEnd<MapperSessionMarker>, Vmo, Option<Port>, Option<Vmo>, MapperOpenSessionResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL