MapperSessionRequest

Enum MapperSessionRequest 

pub enum MapperSessionRequest {
    Close {
        responder: MapperSessionCloseResponder,
    },
    OpenChildSession {
        session: ServerEnd<MapperSessionMarker>,
        mapping_vmo: Vmo,
        parent_key: u64,
        port: Option<Port>,
        delivery_queue: Option<Vmo>,
        responder: MapperSessionOpenChildSessionResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: MapperSessionControlHandle, method_type: MethodType, }, }
Represents an active driver mapping session.

Variants



Close

Terminates the connection.

After calling Close, the client must not send any other requests.

Servers, after sending the status response, should close the connection regardless of status and without sending an epitaph.

Closing the client end of the channel should be semantically equivalent to calling Close without knowing when the close has completed or its status.



OpenChildSession

Opens a child mapper session whose reads map through parent_key in the parent session. When a parent session is closed, all child sessions opened from it are closed as well.

Fields

mapping_vmo: Vmo
parent_key: u64
port: Option<Port>
delivery_queue: Option<Vmo>


#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations