pub struct BlockConnectMapperRequest {
pub server_end: ServerEnd<MapperMarker>,
}Fields
server_end: ServerEnd<MapperMarker>Trait Implementations
Sourceimpl Debug for BlockConnectMapperRequest
impl Debug for BlockConnectMapperRequest
Sourceimpl Decode<BlockConnectMapperRequest, DefaultFuchsiaResourceDialect> for BlockConnectMapperRequest
impl Decode<BlockConnectMapperRequest, DefaultFuchsiaResourceDialect> for BlockConnectMapperRequest
Sourceimpl Encode<BlockConnectMapperRequest, DefaultFuchsiaResourceDialect> for &mut BlockConnectMapperRequest
impl Encode<BlockConnectMapperRequest, DefaultFuchsiaResourceDialect> for &mut BlockConnectMapperRequest
Sourceimpl<T0: Encode<Endpoint<ServerEnd<MapperMarker>>, DefaultFuchsiaResourceDialect>> Encode<BlockConnectMapperRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Endpoint<ServerEnd<MapperMarker>>, DefaultFuchsiaResourceDialect>> Encode<BlockConnectMapperRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl Eq for BlockConnectMapperRequest
Sourceimpl Hash for BlockConnectMapperRequest
impl Hash for BlockConnectMapperRequest
Sourceimpl Ord for BlockConnectMapperRequest
impl Ord for BlockConnectMapperRequest
Sourcefn cmp(&self, other: &BlockConnectMapperRequest) -> Ordering
fn cmp(&self, other: &BlockConnectMapperRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for BlockConnectMapperRequest
impl PartialOrd for BlockConnectMapperRequest
Sourceimpl ResourceTypeMarker for BlockConnectMapperRequest
impl ResourceTypeMarker for BlockConnectMapperRequest
Sourcetype Borrowed<'a> = &'a mut BlockConnectMapperRequest
type Borrowed<'a> = &'a mut BlockConnectMapperRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for BlockConnectMapperRequest
impl StructuralPartialEq for BlockConnectMapperRequest
Sourceimpl TypeMarker for BlockConnectMapperRequest
impl TypeMarker for BlockConnectMapperRequest
Sourcetype Owned = BlockConnectMapperRequest
type Owned = BlockConnectMapperRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for BlockConnectMapperRequest
impl RefUnwindSafe for BlockConnectMapperRequest
impl Send for BlockConnectMapperRequest
impl Sync for BlockConnectMapperRequest
impl Unpin for BlockConnectMapperRequest
impl UnsafeUnpin for BlockConnectMapperRequest
impl UnwindSafe for BlockConnectMapperRequest