pub struct BlockOpenSessionWithOptionsRequest {
pub session: ServerEnd<SessionMarker>,
pub mappings: Vec<BlockOffsetMapping>,
}Fields
session: ServerEnd<SessionMarker>mappings: Vec<BlockOffsetMapping>Trait Implementations
Sourceimpl Decode<BlockOpenSessionWithOptionsRequest, DefaultFuchsiaResourceDialect> for BlockOpenSessionWithOptionsRequest
impl Decode<BlockOpenSessionWithOptionsRequest, DefaultFuchsiaResourceDialect> for BlockOpenSessionWithOptionsRequest
Sourceimpl Encode<BlockOpenSessionWithOptionsRequest, DefaultFuchsiaResourceDialect> for &mut BlockOpenSessionWithOptionsRequest
impl Encode<BlockOpenSessionWithOptionsRequest, DefaultFuchsiaResourceDialect> for &mut BlockOpenSessionWithOptionsRequest
Sourceimpl<T0: Encode<Endpoint<ServerEnd<SessionMarker>>, DefaultFuchsiaResourceDialect>, T1: Encode<Vector<BlockOffsetMapping, 4>, DefaultFuchsiaResourceDialect>> Encode<BlockOpenSessionWithOptionsRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<Endpoint<ServerEnd<SessionMarker>>, DefaultFuchsiaResourceDialect>, T1: Encode<Vector<BlockOffsetMapping, 4>, DefaultFuchsiaResourceDialect>> Encode<BlockOpenSessionWithOptionsRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl Eq for BlockOpenSessionWithOptionsRequest
Sourceimpl Ord for BlockOpenSessionWithOptionsRequest
impl Ord for BlockOpenSessionWithOptionsRequest
Sourcefn cmp(&self, other: &BlockOpenSessionWithOptionsRequest) -> Ordering
fn cmp(&self, other: &BlockOpenSessionWithOptionsRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockOpenSessionWithOptionsRequest
impl PartialEq for BlockOpenSessionWithOptionsRequest
Sourcefn eq(&self, other: &BlockOpenSessionWithOptionsRequest) -> bool
fn eq(&self, other: &BlockOpenSessionWithOptionsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BlockOpenSessionWithOptionsRequest
impl PartialOrd for BlockOpenSessionWithOptionsRequest
Sourceimpl ResourceTypeMarker for BlockOpenSessionWithOptionsRequest
impl ResourceTypeMarker for BlockOpenSessionWithOptionsRequest
Sourcetype Borrowed<'a> = &'a mut BlockOpenSessionWithOptionsRequest
type Borrowed<'a> = &'a mut BlockOpenSessionWithOptionsRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for BlockOpenSessionWithOptionsRequest
impl StructuralPartialEq for BlockOpenSessionWithOptionsRequest
Sourceimpl TypeMarker for BlockOpenSessionWithOptionsRequest
impl TypeMarker for BlockOpenSessionWithOptionsRequest
Sourcetype Owned = BlockOpenSessionWithOptionsRequest
type Owned = BlockOpenSessionWithOptionsRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for BlockOpenSessionWithOptionsRequest
impl RefUnwindSafe for BlockOpenSessionWithOptionsRequest
impl Send for BlockOpenSessionWithOptionsRequest
impl Sync for BlockOpenSessionWithOptionsRequest
impl Unpin for BlockOpenSessionWithOptionsRequest
impl UnsafeUnpin for BlockOpenSessionWithOptionsRequest
impl UnwindSafe for BlockOpenSessionWithOptionsRequest