pub struct BlockSynchronousProxy { /* private fields */ }Implementations
Sourceimpl BlockSynchronousProxy
impl BlockSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<BlockEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<BlockEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_info(
&self,
___deadline: MonotonicInstant,
) -> Result<BlockGetInfoResult, Error>
pub fn get_info( &self, ___deadline: MonotonicInstant, ) -> Result<BlockGetInfoResult, Error>
Get information about the underlying block device.
Sourcepub fn open_session(
&self,
session: ServerEnd<SessionMarker>,
) -> Result<(), Error>
pub fn open_session( &self, session: ServerEnd<SessionMarker>, ) -> Result<(), Error>
Opens a new FIFO-based session on the block device.
Sourcepub fn open_session_with_options(
&self,
session: ServerEnd<SessionMarker>,
mappings: &[BlockOffsetMapping],
) -> Result<(), Error>
pub fn open_session_with_options( &self, session: ServerEnd<SessionMarker>, mappings: &[BlockOffsetMapping], ) -> Result<(), Error>
Opens a new FIFO-based session on the block device, with additional options.
Mappings
The mappings argument is a list of logical -> physical block mappings, which the server
will transparently apply to device offsets in block FIFO requests within this session.
The mappings are logically contiguous starting from logical offset 0.
This interface is intended to be used internally between nested Block implementations, in order to provide passthrough I/O. For example, a fixed partition map (e.g. GPT) will serve a Block protocol for each partition, and will respond to OpenSession requests by calling OpenSessionWithOptions on the underlying block device, providing mappings which translate block offsets which are relative to (and bounded by) the partition to absolute offsets on the device.
Mappings can only ever restrict the visible range of a device; servers will reject mappings which exceed the range of the device.
If mappings is empty, the session channel will be closed with epitaph
ZX_ERR_INVALID_ARGS.
Sourcepub fn get_type_guid(
&self,
___deadline: MonotonicInstant,
) -> Result<(i32, Option<Box<Guid>>), Error>
pub fn get_type_guid( &self, ___deadline: MonotonicInstant, ) -> Result<(i32, Option<Box<Guid>>), Error>
Gets the type GUID of the partition (if one exists). If the partition has no type GUID, ZX_ERR_NOT_SUPPORTED is returned.
Sourcepub fn get_instance_guid(
&self,
___deadline: MonotonicInstant,
) -> Result<(i32, Option<Box<Guid>>), Error>
pub fn get_instance_guid( &self, ___deadline: MonotonicInstant, ) -> Result<(i32, Option<Box<Guid>>), Error>
Gets the instance GUID of the partition (if one exists). If the partition has no instance GUID, ZX_ERR_NOT_SUPPORTED is returned.
Sourcepub fn get_name(
&self,
___deadline: MonotonicInstant,
) -> Result<(i32, Option<String>), Error>
pub fn get_name( &self, ___deadline: MonotonicInstant, ) -> Result<(i32, Option<String>), Error>
Gets the name of the partition (if one exists). If the partition has no name, ZX_ERR_NOT_SUPPORTED is returned.
Sourcepub fn get_metadata(
&self,
___deadline: MonotonicInstant,
) -> Result<BlockGetMetadataResult, Error>
pub fn get_metadata( &self, ___deadline: MonotonicInstant, ) -> Result<BlockGetMetadataResult, Error>
Gets the metadata for the partition.
Fields may be absent if the partition doesn’t have the given metadata.
Sourcepub fn query_slices(
&self,
start_slices: &[u64],
___deadline: MonotonicInstant,
) -> Result<(i32, [VsliceRange; 16], u64), Error>
pub fn query_slices( &self, start_slices: &[u64], ___deadline: MonotonicInstant, ) -> Result<(i32, [VsliceRange; 16], u64), Error>
Returns the number of contiguous allocated (or unallocated) vslices starting from each vslice.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Sourcepub fn get_volume_info(
&self,
___deadline: MonotonicInstant,
) -> Result<(i32, Option<Box<VolumeManagerInfo>>, Option<Box<VolumeInfo>>), Error>
pub fn get_volume_info( &self, ___deadline: MonotonicInstant, ) -> Result<(i32, Option<Box<VolumeManagerInfo>>, Option<Box<VolumeInfo>>), Error>
Returns the information about this volume and the volume manager it is embedded in.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Sourcepub fn extend(
&self,
start_slice: u64,
slice_count: u64,
___deadline: MonotonicInstant,
) -> Result<i32, Error>
pub fn extend( &self, start_slice: u64, slice_count: u64, ___deadline: MonotonicInstant, ) -> Result<i32, Error>
Extends the mapping of this partition.
The ability to extend the partition is dependent on having sufficient free space on the underlying device, having sufficient free slots for tracking the bytes in the volume manager header, and the partition limit (see VolumeManager.SetPartitionLimit).
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.
Sourcepub fn shrink(
&self,
start_slice: u64,
slice_count: u64,
___deadline: MonotonicInstant,
) -> Result<i32, Error>
pub fn shrink( &self, start_slice: u64, slice_count: u64, ___deadline: MonotonicInstant, ) -> Result<i32, Error>
Shrinks a virtual partition. Returns ZX_OK if ANY slices are
freed, even if part of the requested range contains unallocated slices.
Returns ZX_ERR_NOT_SUPPORTED if the device is not a volume.