pub struct CreateVmoOptions(/* private fields */);Expand description
Options for MapperSession.CreateVmo.
Implementations
Sourceimpl CreateVmoOptions
impl CreateVmoOptions
Sourcepub const SUPPLY_ZEROES_ON_ERROR: CreateVmoOptions
pub const SUPPLY_ZEROES_ON_ERROR: CreateVmoOptions
If set, I/O errors during page faults supply zero-filled pages and assert
ZX_USER_SIGNAL_0 on the VMO instead of failing the page request with ZX_ERR_IO.
Sourceimpl CreateVmoOptions
impl CreateVmoOptions
Sourcepub const fn empty() -> CreateVmoOptions
pub const fn empty() -> CreateVmoOptions
Get a flags value with all bits unset.
Sourcepub const fn all() -> CreateVmoOptions
pub const fn all() -> CreateVmoOptions
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<CreateVmoOptions>
pub const fn from_bits(bits: u32) -> Option<CreateVmoOptions>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> CreateVmoOptions
pub const fn from_bits_truncate(bits: u32) -> CreateVmoOptions
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> CreateVmoOptions
pub const fn from_bits_retain(bits: u32) -> CreateVmoOptions
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CreateVmoOptions>
pub fn from_name(name: &str) -> Option<CreateVmoOptions>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CreateVmoOptions) -> bool
pub const fn intersects(&self, other: CreateVmoOptions) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: CreateVmoOptions) -> bool
pub const fn contains(&self, other: CreateVmoOptions) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: CreateVmoOptions)
pub fn insert(&mut self, other: CreateVmoOptions)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: CreateVmoOptions)
pub fn remove(&mut self, other: CreateVmoOptions)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CreateVmoOptions)
pub fn toggle(&mut self, other: CreateVmoOptions)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: CreateVmoOptions, value: bool)
pub fn set(&mut self, other: CreateVmoOptions, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CreateVmoOptions) -> CreateVmoOptions
pub const fn intersection(self, other: CreateVmoOptions) -> CreateVmoOptions
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: CreateVmoOptions) -> CreateVmoOptions
pub const fn union(self, other: CreateVmoOptions) -> CreateVmoOptions
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: CreateVmoOptions) -> CreateVmoOptions
pub const fn difference(self, other: CreateVmoOptions) -> CreateVmoOptions
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: CreateVmoOptions,
) -> CreateVmoOptions
pub const fn symmetric_difference( self, other: CreateVmoOptions, ) -> CreateVmoOptions
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> CreateVmoOptions
pub const fn complement(self) -> CreateVmoOptions
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CreateVmoOptions
impl CreateVmoOptions
Sourcepub const fn iter(&self) -> Iter<CreateVmoOptions> ⓘ
pub const fn iter(&self) -> Iter<CreateVmoOptions> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CreateVmoOptions> ⓘ
pub const fn iter_names(&self) -> IterNames<CreateVmoOptions> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.