pub struct MapperMarker;Trait Implementations
Sourceimpl Clone for MapperMarker
impl Clone for MapperMarker
Sourcefn clone(&self) -> MapperMarker
fn clone(&self) -> MapperMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MapperMarker
Sourceimpl Debug for MapperMarker
impl Debug for MapperMarker
Sourceimpl DiscoverableProtocolMarker for MapperMarker
impl DiscoverableProtocolMarker for MapperMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for MapperMarker
Sourceimpl Hash for MapperMarker
impl Hash for MapperMarker
Sourceimpl Ord for MapperMarker
impl Ord for MapperMarker
Sourcefn cmp(&self, other: &MapperMarker) -> Ordering
fn cmp(&self, other: &MapperMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MapperMarker
impl PartialEq for MapperMarker
Sourceimpl PartialOrd for MapperMarker
impl PartialOrd for MapperMarker
Sourceimpl ProtocolMarker for MapperMarker
impl ProtocolMarker for MapperMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.storage.block.Mapper"
const DEBUG_NAME: &'static str = "fuchsia.storage.block.Mapper"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MapperProxy
type Proxy = MapperProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MapperRequestStream
type RequestStream = MapperRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MapperSynchronousProxy
type SynchronousProxy = MapperSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MapperMarker