pub struct MapperSessionMarker;Trait Implementations
Sourceimpl Clone for MapperSessionMarker
impl Clone for MapperSessionMarker
Sourcefn clone(&self) -> MapperSessionMarker
fn clone(&self) -> MapperSessionMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MapperSessionMarker
Sourceimpl Debug for MapperSessionMarker
impl Debug for MapperSessionMarker
impl Eq for MapperSessionMarker
Sourceimpl Hash for MapperSessionMarker
impl Hash for MapperSessionMarker
Sourceimpl Ord for MapperSessionMarker
impl Ord for MapperSessionMarker
Sourcefn cmp(&self, other: &MapperSessionMarker) -> Ordering
fn cmp(&self, other: &MapperSessionMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for MapperSessionMarker
impl PartialEq for MapperSessionMarker
Sourceimpl PartialOrd for MapperSessionMarker
impl PartialOrd for MapperSessionMarker
Sourceimpl ProtocolMarker for MapperSessionMarker
impl ProtocolMarker for MapperSessionMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) MapperSession"
const DEBUG_NAME: &'static str = "(anonymous) MapperSession"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MapperSessionProxy
type Proxy = MapperSessionProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MapperSessionRequestStream
type RequestStream = MapperSessionRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MapperSessionSynchronousProxy
type SynchronousProxy = MapperSessionSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MapperSessionMarker