pub struct MapperSessionProxy { /* private fields */ }Implementations
Sourceimpl MapperSessionProxy
impl MapperSessionProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.storage.block/MapperSession.
Sourcepub fn take_event_stream(&self) -> MapperSessionEventStream
pub fn take_event_stream(&self) -> MapperSessionEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn close(
&self,
) -> QueryResponseFut<CloseableCloseResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn close( &self, ) -> QueryResponseFut<CloseableCloseResult, DefaultFuchsiaResourceDialect> ⓘ
Terminates the connection.
After calling Close, the client must not send any other requests.
Servers, after sending the status response, should close the connection regardless of status and without sending an epitaph.
Closing the client end of the channel should be semantically equivalent
to calling Close without knowing when the close has completed or its
status.
Sourcepub fn open_child_session(
&self,
session: ServerEnd<MapperSessionMarker>,
mapping_vmo: Vmo,
parent_key: u64,
port: Option<Port>,
delivery_queue: Option<Vmo>,
) -> QueryResponseFut<MapperSessionOpenChildSessionResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn open_child_session( &self, session: ServerEnd<MapperSessionMarker>, mapping_vmo: Vmo, parent_key: u64, port: Option<Port>, delivery_queue: Option<Vmo>, ) -> QueryResponseFut<MapperSessionOpenChildSessionResult, DefaultFuchsiaResourceDialect> ⓘ
Opens a child mapper session whose reads map through parent_key in the parent session.
When a parent session is closed, all child sessions opened from it are closed as well.