MapperSessionSynchronousProxy

Struct MapperSessionSynchronousProxy 

pub struct MapperSessionSynchronousProxy { /* private fields */ }

Implementations

Source

impl MapperSessionSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<MapperSessionEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn close( &self, ___deadline: MonotonicInstant, ) -> Result<CloseableCloseResult, Error>

Terminates the connection.

After calling Close, the client must not send any other requests.

Servers, after sending the status response, should close the connection regardless of status and without sending an epitaph.

Closing the client end of the channel should be semantically equivalent to calling Close without knowing when the close has completed or its status.

pub fn open_child_session( &self, session: ServerEnd<MapperSessionMarker>, mapping_vmo: Vmo, parent_key: u64, port: Option<Port>, delivery_queue: Option<Vmo>, ___deadline: MonotonicInstant, ) -> Result<MapperSessionOpenChildSessionResult, Error>

Opens a child mapper session whose reads map through parent_key in the parent session. When a parent session is closed, all child sessions opened from it are closed as well.