PartitionInfo

Struct PartitionInfo 

pub struct PartitionInfo {
    pub name: Option<String>,
    pub type_guid: Option<Guid>,
    pub instance_guid: Option<Guid>,
    pub start_block_offset: Option<u64>,
    pub num_blocks: Option<u64>,
    pub flags: Option<u64>,
    /* private fields */
}
Metadata describing a partition.

Fields

name: Option<String>type_guid: Option<Guid>instance_guid: Option<Guid>start_block_offset: Option<u64>num_blocks: Option<u64>

num_blocks will be absent if the partition is a volume, which is dynamically sized and can grow via fuchsia.storage.block.Block/Extend. To get the current size, use fuchsia.storage.block.Block/GetVolumeInfo.

flags: Option<u64>

The partition table entry flags (for example, in a GPT partition, the GPT partition table entry flags). Note that this is distinct from the device flags returned in BlockInfo.