pub enum MapperSessionRequest {
Close {
responder: MapperSessionCloseResponder,
},
OpenChildSession {
session: ServerEnd<MapperSessionMarker>,
mapping_vmo: Vmo,
parent_key: u64,
port: Option<Port>,
delivery_queue: Option<Vmo>,
responder: MapperSessionOpenChildSessionResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: MapperSessionControlHandle,
method_type: MethodType,
},
}Expand description
Represents an active driver mapping session.
Variants
Close
Terminates the connection.
After calling Close, the client must not send any other requests.
Servers, after sending the status response, should close the connection regardless of status and without sending an epitaph.
Closing the client end of the channel should be semantically equivalent
to calling Close without knowing when the close has completed or its
status.
Fields

responder: MapperSessionCloseResponderOpenChildSession
Opens a child mapper session whose reads map through parent_key in the parent session.
When a parent session is closed, all child sessions opened from it are closed as well.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: MapperSessionControlHandle
method_type: MethodTypeImplementations
Sourceimpl MapperSessionRequest
impl MapperSessionRequest
pub fn into_close(self) -> Option<MapperSessionCloseResponder>
pub fn into_open_child_session( self, ) -> Option<(ServerEnd<MapperSessionMarker>, Vmo, u64, Option<Port>, Option<Vmo>, MapperSessionOpenChildSessionResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL